@@ -105,8 +105,8 @@ class Transcription(models.Model):
 
 
     def get_neigh_densities(self):
-        if self.nd is not None and self.fwnd is not None:
-            return self.nd,self.fwnd
+        if self.neigh_den is not None and self.fwnd is not None:
+            return self.neigh_den,self.fwnd
         any_segment = '.'
         phones = self.strip_transcription()
         patterns = []
@@ -128,10 +128,10 @@ class Transcription(models.Model):
                     params = ['|'.join(patterns)])
         nd = len(neighs)
         fwnd = sum([ x.getFreq() for x in neighs])
-        self.nd = nd
+        self.neigh_den = nd
         self.fwnd = fwnd
         self.save()
-        return self.nd,self.fwnd
+        return self.neigh_den,self.fwnd
 
     #def getCVStruct(self):
     #    if self.CVSkel is not None:
@@ -181,6 +181,9 @@ class WordForm(models.Model):
     def get_cond_prob_of_spelling(self,orth):
         count = self.spelledas_set.filter(orthography=orth)[0].frequency
         totcount = self.spelledas_set.all().aggregate(totcount = Sum('frequency'))['totcount']
+        if totcount == 0:
+            print self
+            print [(x.orthography,x.frequency) for x in self.spelledas_set.all()]
         return float(count)/float(totcount)
 
     def get_norm_frequency(self):
